==> pano_rtc-0.9.3.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/events/RtcWhiteboardEvent.kt <==
package video.pano.pano_rtc.events

import com.pano.rtc.api.Constants
import com.pano.rtc.api.RtcWhiteboard

class WhiteboardEvent(
        private val emit: (methodName: String, data: Map<String, Any?>?) -> Unit
) : RtcWhiteboard.Callback {

    private fun callback(methodName: String, vararg data: Any?) {
        emit(methodName, hashMapOf("data" to data.toList()))
    }

    override fun onImageStateChanged(url: String?, state: Constants.WBImageState?) {
        callback("onImageStateChanged", url, state?.value)
    }

    override fun onSnapshotComplete(result: Constants.QResult?, filename: String?) {
        callback("onSnapshotComplete", result?.value, filename)
    }

    override fun onRoleTypeChanged(newRole: Constants.WBRoleType?) {
        callback("onRoleTypeChanged", newRole?.value)
    }

    override fun onUserJoined(userId: Long, userName: String?) {
        callback("onUserJoined", userId, userName)
    }

    override fun onPageNumberChanged(curPage: Int, totalPages: Int) {
        callback("onPageNumberChanged", curPage, totalPages)
    }

    override fun onContentUpdated() {
        callback("onContentUpdated")
    }

    override fun onSaveDoc(result: Constants.QResult?, fileId: String?, outputDir: String?) {
        callback("onSaveDoc", result?.value, fileId, outputDir)
    }

    override fun onCreateDoc(result: Constants.QResult?, fileId: String?) {
        callback("onSaveDoc", result?.value, fileId)
    }

    override fun onDeleteDoc(result: Constants.QResult?, fileId: String?) {
        callback("onDeleteDoc", result?.value, fileId)
    }

    override fun onDocTranscodeStatus(result: Constants.QResult?, fileId: String?, progress: Int, totalPage: Int) {
        callback("onDeleteDoc", result?.value, fileId, progress, totalPage)
    }

    override fun onAddBackgroundImages(result: Constants.QResult?, fileId: String?) {
        callback("onAddBackgroundImages", result?.value, fileId)
    }

    override fun onStatusSynced() {
        callback("onStatusSynced")
    }

    override fun onMessage(userId: Long, bytes: ByteArray?) {
        callback("onMessage", userId, bytes)
    }

    override fun onViewScaleChanged(scale: Float) {
        callback("onViewScaleChanged", scale)
    }

    override fun onSwitchDoc(result: Constants.QResult?, fileId: String?) {
        callback("onSwitchDoc", result?.value, fileId)
    }

    override fun onUserLeft(userId: Long) {
        callback("onSwitchDoc", userId)
    }
}

==> pano_rtc-0.9.4-dev.4.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/events/RtcWhiteboardEvent.kt <==
package video.pano.pano_rtc.events

import com.pano.rtc.api.Constants
import com.pano.rtc.api.RtcWhiteboard

class WhiteboardEvent(
        private val emit: (methodName: String, data: Map<String, Any?>?) -> Unit
) : RtcWhiteboard.Callback {

    private fun callback(methodName: String, vararg data: Any?) {
        emit(methodName, hashMapOf("data" to data.toList()))
    }

    override fun onImageStateChanged(url: String?, state: Constants.WBImageState?) {
        callback("onImageStateChanged", url, state?.value)
    }

    override fun onSnapshotComplete(result: Constants.QResult?, filename: String?) {
        callback("onSnapshotComplete", result?.value, filename)
    }

    override fun onRoleTypeChanged(newRole: Constants.WBRoleType?) {
        callback("onRoleTypeChanged", newRole?.value)
    }

    override fun onUserJoined(userId: Long, userName: String?) {
        callback("onUserJoined", userId, userName)
    }

    override fun onPageNumberChanged(curPage: Int, totalPages: Int) {
        callback("onPageNumberChanged", curPage, totalPages)
    }

    override fun onContentUpdated() {
        callback("onContentUpdated")
    }

    override fun onSaveDoc(result: Constants.QResult?, fileId: String?, outputDir: String?) {
        callback("onSaveDoc", result?.value, fileId, outputDir)
    }

    override fun onCreateDoc(result: Constants.QResult?, fileId: String?) {
        callback("onCreateDoc", result?.value, fileId)
    }

    override fun onDeleteDoc(result: Constants.QResult?, fileId: String?) {
        callback("onDeleteDoc", result?.value, fileId)
    }

    override fun onDocTranscodeStatus(result: Constants.QResult?, fileId: String?, progress: Int, totalPage: Int) {
        callback("onDocTranscodeStatus", result?.value, fileId, progress, totalPage)
    }

    override fun onAddBackgroundImages(result: Constants.QResult?, fileId: String?) {
        callback("onAddBackgroundImages", result?.value, fileId)
    }

    override fun onStatusSynced() {
        callback("onStatusSynced")
    }

    override fun onMessage(userId: Long, bytes: ByteArray?) {
        callback("onMessage", userId, bytes)
    }

    override fun onViewScaleChanged(scale: Float) {
        callback("onViewScaleChanged", scale)
    }

    override fun onSwitchDoc(result: Constants.QResult?, fileId: String?) {
        callback("onSwitchDoc", result?.value, fileId)
    }

    override fun onUserLeft(userId: Long) {
        callback("onUserLeft", userId)
    }
}
